#ifndef __CTDTRACKER__
#define __CTDTRACKER__
//*************************************************************************
//* =================
//*  CTDTracker Class
//* =================
//*
//* (Description)
//*    Tracker class.
//* (Requires)
//*	class CTDLayer
//* (Provides)
//* 	class CTDTracker
//* (Update Recored)
//*    1999/11/08  K.Fujii	Original version.
//*
//*************************************************************************
//
#include "TObjArray.h"
#include "CTDLayer.h"
//_____________________________________________________________________
//  ----------
//  CTDTracker
//  ----------
//
class CTDTracker : public TObjArray {
public:
   CTDTracker() : fSorted(kFALSE), fFilled(kFALSE), fErrorSet(kFALSE),
   		  fError(3,3), fErrorIP(2,2) {}
   virtual ~CTDTracker() { Delete(); }

   void DebugPrint(const Char_t *opt="Brief");
   void Sort(Int_t upto = kMaxInt);
   void FillGapByAir(Double_t x0air = CTDLayer::kX0Air);

   Double_t GetSigmaKappa   (Double_t p, Double_t tanl);
   Double_t GetSigmaKappaIP (Double_t p, Double_t tanl);

private:
   TMatrix MovePivot(Int_t inward, const CTDLayer &layer, const TMatrix &error);
   void    CalculateErrorMatrix(Double_t p, Double_t tanl);

private:
   Bool_t  fSorted;	// flag to tell if layers are sorted
   Bool_t  fFilled;	// flag to tell if layers are filled
   Bool_t  fErrorSet;	// flag to tell if error matrices are set
   TMatrix fError;	// error matrix
   TMatrix fErrorIP;	// error matrix w/ IP constraint

   ClassDef(CTDTracker,1)  // Tracker class
};

#endif
